@@ -1,8 +1,8 @@
 ;;; -*- Emacs-Lisp -*-
 ;;; Window manager for GNU Emacs.
-;;; $Id: windows.el,v 2.40 2004/10/30 07:18:29 yuuji Exp yuuji $
-;;; (c) 1993-2005 by HIROSE Yuuji [yuuji@gentei.org]
-;;; Last modified Sun Sep 18 23:55:55 2005 on firestorm
+;;; $Id: windows.el,v 2.41 2007/06/06 11:29:29 yuuji Exp $
+;;; (c) 1993-2007 by HIROSE Yuuji [yuuji@gentei.org]
+;;; Last modified Wed Jun  6 20:29:19 2007 on firestorm
 
 ;;;		Window manager for GNU Emacs
 ;;;
@@ -35,6 +35,18 @@
 ;;;	   (win:startup-with-window)
 ;;;	   (define-key ctl-x-map "C" 'see-you-again)
 ;;;
+;;;[Hack]
+;;;
+;;;	  If your are thinking of creating patch for windows.el, please
+;;;	don't forget to consider about compatibility of various emacsen.
+;;;	
+;;;		* Do not rely on other package.  e.g., 'when relies on
+;;;		  'cl package.
+;;;		* Test your patch on as old/new emacs as you can have.
+;;;	
+;;;	Anyway, feel free to hack.  I'll make a glue for various emacsen
+;;;	upon your patches if you can't test.
+;;;
 ;;;[Key Bindings]
 ;;;
 ;;;	  The default prefix key stroke for Windows is `C-c C-w'.  If it
@@ -95,7 +107,7 @@
 ;;;	create the buffer 2,  and  you  will  see  the  `window creation
 ;;;	menu':
 ;;;
-;;;		C)reate D)uplicate P)reserve F)indfile B)uff X)M-x N)o:
+;;;  C)reate D)uplicate P)reserve F)indfile B)uff X)M-x k)KeyFunc&exit N)o:
 ;;;
 ;;;	in the  minibuffer.   Since  you don't need  the current  window
 ;;;	configuration  (programming  configuration) to read  mails, type
@@ -613,7 +625,7 @@
 ;;;	ץѤʤ̤ФƤԤϰڤǤ
 ;;;	ʤΤȤޤȤХݡȤ礤˴
 ;;;	ޤڤˤϢϢϰʲΥɥ쥹ޤǤꤤ
-;;;	ޤ(2002/9)
+;;;	ޤ(2007/6)
 ;;;							yuuji@gentei.org
 
 ;;;
@@ -1067,6 +1079,15 @@ Non-nil for ARG kills all visible buffer."
 		(kill-buffer (car blist)))
 	    (setq blist (cdr blist)))))))
 
+(defun win:kill-buffer-with-window ()
+  "Kill current window if it was created by KeyFunc&Exit."
+  (and win:kill-buffer-with
+       (equal win:current-config win:kill-buffer-with)
+       (win:delete-window win:current-config nil t)))
+
+(defvar win:kill-buffer-with nil
+  "If win:current-config is equal to this, delete this window.")
+(make-variable-buffer-local 'win:kill-buffer-with)
 ;;;###autoload
 (defun win-switch-to-window (arg &optional window)
   "Switch window configurations to a buffer specified by keyboard.
@@ -1150,14 +1171,8 @@ the window number."
 		    (sit-for 0)
 		    (setq inhibitmsg t)
 		    (call-interactively cmd)
-		    (make-local-variable 'kill-buffer-hook)
-		    (add-hook 'kill-buffer-hook
-			      (list 'lambda nil
-				    (list 'win:delete-window
-					  win:current-config
-					  nil t
-					  )))
-		    ))
+		    (setq win:kill-buffer-with win:current-config)
+		    (add-hook 'kill-buffer-hook 'win:kill-buffer-with-window)))
 		 ((and (string-match (char-to-string ans) "py")
 		       (null win:use-frame))
 		  (win:switch-window window t t))
@@ -1521,7 +1536,7 @@ Do not call this function."
 ;; Functions for resume.
 ;;;
 (defconst win:revision
-  "$Revision: 2.40 $"
+  "$Revision: 2.41 $"
   "Revision string of windows.el")
 (defvar win:revision-prefix ";win;")
 
@@ -2229,6 +2244,14 @@ If interactive argument KILL is non-nil, kill menu buffer and no select."
 (run-hooks 'win-load-hook)
 
 ;; $Log: windows.el,v $
+;; Revision 2.41  2007/06/06 11:29:29  yuuji
+;; Fix hook setup for KeyFunc&Exit.
+;; Suggested by Debian Project.
+;;
+;; Revision 2.41  2007/06/06 11:28:05  yuuji
+;; Fix hook setup for KeyFunc&Exit.
+;; Suggested by Debian Project.
+;;
 ;; Revision 2.40  2004/10/30 07:18:29  yuuji
 ;; New flag win:config-loaded introduced for external utility.
 ;;
